<!-- Copyright: © 2024 Jonathan Fox
License: GNU AGPL, version 3 or later; http://www.gnu.org/licenses/agpl.html
Full source code: https://github.com/jonathanfox5/gogadget -->

## Licences for materials included in main application repository

--8<-- "docs/pages/license_info/acknowledgements.md"

## Licences for all python dependencies

The `LICENSE` files for all dependencies will be installed to your storage alongside the packages. For easy reference, all of the licenses and authors are displayed below, as automatically generated by `pip-licenses`.

??? note "`UNKNOWN` licenses"

    `audioread` displays as `UNKNOWN` in the table below due to a misconfiguration in the pypi package. It is `MIT` licensed [as per the github listing](https://github.com/beetbox/audioread/blob/main/LICENSE).

Auto-generated list of python dependencies:

--8<-- "src/gogadget/3rd-party-licenses/license_listing_for_python_dependencies.md"
